==> GeneticsBase_1.0.0.tar.gz: GeneticsBase/R/geneSet-methods.R <==

## callCodes:  accessor and replacement methods
setGeneric("callCodes", function(object, marker)
           standardGeneric("callCodes"))

setMethod("callCodes", "geneSet", function(object, marker)
          if(missing(marker))
             object@callCodes
          else
             object@callCodes[marker,]
             )

setGeneric("callCodes<-", function(object, value)
           standardGeneric("callCodes<-"))

setReplaceMethod("callCodes", "geneSet", function(object, value) {
	object@callCodes <- value
	return(object)
})

## errorMetrics:  Accessor and replacement methods
setGeneric("errorMetrics", function(object)
           standardGeneric("errorMetrics"))

setMethod("errorMetrics", "geneSet", function(object)
	object@errorMetrics) 

setGeneric("errorMetrics<-", function(object, value)
           standardGeneric("errorMetrics<-"))

setReplaceMethod("errorMetrics", "geneSet", function(object,
	value){
	object@errorMetrics <- value
	return(object)
})


## sampleInfo:  Accessor and replacement methods
setGeneric("sampleInfo", function(object, ...)
           standardGeneric("sampleInfo"))

setMethod("sampleInfo", "geneSet", function(object, ...)
	object@sampleInfo)

setGeneric("sampleInfo<-", function(object, value)
           standardGeneric("sampleInfo<-"))

setReplaceMethod("sampleInfo", "geneSet", function(object, value) {
	object@sampleInfo <- value
	return(object)
})

## markerInfo:  Accessor and replacement methods
setGeneric("markerInfo", function(object, ...)
           standardGeneric("markerInfo"))

setMethod("markerInfo", "geneSet", function(object, ...)
	object@markerInfo)

setGeneric("markerInfo<-", function(object, value)
           standardGeneric("markerInfo<-"))

setReplaceMethod("markerInfo", "geneSet", 
	function(object, value) {
		# check whether "Name", "Coding" fields exist,if not,Stop!
		object@markerInfo <- value
		return(object)
})


# number of genetic markers
setGeneric("nmarker", function(object)
           standardGeneric("nmarker"))

setMethod("nmarker", "geneSet",
          function(object) nrow(object@markerInfo) )

# number of observations markers
setGeneric("nobs",
           function(x, ...) standardGeneric("nobs") )

setMethod("nobs", "geneSet",
          function(x, ...) ncol(x@callCodes) )

## studyInfo:  Accessor and replacement methods
setGeneric("studyInfo", function(object)
           standardGeneric("studyInfo"))

setMethod("studyInfo", "geneSet", function(object)
	object@studyInfo)

setGeneric("studyInfo<-", function(object, value)
           standardGeneric("studyInfo<-"))

setReplaceMethod("studyInfo", "geneSet", function(object, value) {
	object@studyInfo <- value
	return(object)
})

## description:  Accessor and replacement methods
setGeneric("description", function(object)
	standardGeneric("description"))

setMethod("description", "geneSet", function(object)
	object@description)

setGeneric("description<-", function(object, value)
           standardGeneric("description<-"))

setReplaceMethod("description", "geneSet",
	function(object, value) {
		object@description <- value
		return(object)
})

## notes:  Accessor and replacement methods
setGeneric("notes", function(object)
           standardGeneric("notes"))

setMethod("notes", "geneSet", function(object)
	object@notes)

setGeneric("notes<-", function(object, value)
           standardGeneric("notes<-"))

setReplaceMethod("notes", "geneSet", function(object, value) {
	object@notes <- value
	return(object)
})

## ploidy:  Accessor and replacement methods
setGeneric("ploidy", function(object)
           standardGeneric("ploidy"))

setMethod("ploidy", "geneSet", function(object)
	object@ploidy)

setGeneric("ploidy<-", function(object, value)
           standardGeneric("ploidy<-"))

setReplaceMethod("ploidy", "geneSet", function(object, value) {
	object@ploidy <- value
	return(object)
})

## phase:  Accessor and replacement methods
setGeneric("phase", function(object)
           standardGeneric("phase"))

setMethod("phase", "geneSet", function(object)
	object@phase)

setGeneric("phase<-", function(object, value)
           standardGeneric("phase<-"))

setReplaceMethod("phase", "geneSet", function(object, value) {
	object@phase <- value
	return(object)
})


# Extract marker names
setGeneric("markerNames", function(object, ...)
           standardGeneric("markerNames"))


setMethod("markerNames", "geneSet",
          function(object, codes=FALSE)
            as.character(object@markerInfo$Name)
          )

## Extract alleles 
setGeneric("alleles", function(object, ...)
           standardGeneric("alleles"))


setMethod("alleles", "geneSet",
          function(object, which=c(1,2), codes=FALSE, marker )
            extractAlleles(object, which=which, codes=codes, marker=marker)
          )

## Extract genotypes
setGeneric("genotypes", 
           function(object, ...)
           standardGeneric("genotypes"))


setMethod("genotypes", "geneSet", function(object, codes=FALSE, marker)
            extractAlleles(object, which=0, codes=codes, marker=marker)
          )


## Number of alleles 
setGeneric("nallele", function(object, ...)
           standardGeneric("nallele"))


setMethod("nallele", "geneSet",
          function(object, marker=1:nmarker(object) )
            sapply( alleleLevels(object,marker),
                   function(x) length(na.omit(x)))
          )

==> GeneticsBase_1.14.0.tar.gz: GeneticsBase/R/geneSet-methods.R <==

## callCodes:  accessor and replacement methods
setGeneric("callCodes", function(object, marker)
           standardGeneric("callCodes"))

setMethod("callCodes", "geneSet", function(object, marker)
          if(missing(marker))
             object@callCodes
          else
             object@callCodes[marker,, drop=FALSE]
             )

setGeneric("callCodes<-", function(object, value)
           standardGeneric("callCodes<-"))

setReplaceMethod("callCodes", "geneSet", function(object, value) {
	object@callCodes <- value
	return(object)
})

## errorMetrics:  Accessor and replacement methods
setGeneric("errorMetrics", function(object)
           standardGeneric("errorMetrics"))

setMethod("errorMetrics", "geneSet", function(object)
	object@errorMetrics) 

setGeneric("errorMetrics<-", function(object, value)
           standardGeneric("errorMetrics<-"))

setReplaceMethod("errorMetrics", "geneSet", function(object,
	value){
	object@errorMetrics <- value
	return(object)
})


## sampleInfo:  Accessor and replacement methods
setGeneric("sampleInfo", function(object, ...)
           standardGeneric("sampleInfo"))

setMethod("sampleInfo", "geneSet", function(object, ...)
	object@sampleInfo)

setGeneric("sampleInfo<-", function(object, value)
           standardGeneric("sampleInfo<-"))

setReplaceMethod("sampleInfo", "geneSet", function(object, value) {
	object@sampleInfo <- value
	return(object)
})

## markerInfo:  Accessor and replacement methods
setGeneric("markerInfo", function(object, ...)
           standardGeneric("markerInfo"))

setMethod("markerInfo", "geneSet", function(object, ...)
	object@markerInfo)

setGeneric("markerInfo<-", function(object, value)
           standardGeneric("markerInfo<-"))

setReplaceMethod("markerInfo", "geneSet", 
	function(object, value) {
		# check whether "Name", "Coding" fields exist,if not,Stop!
		object@markerInfo <- value
		return(object)
})


# number of genetic markers
setGeneric("nmarker", function(object)
           standardGeneric("nmarker"))

setMethod("nmarker", "geneSet",
          function(object) nrow(object@markerInfo) )

# number of observations markers
setGeneric("nobs",
           function(x, ...) standardGeneric("nobs") )

setMethod("nobs", "geneSet",
          function(x, ...) ncol(x@callCodes) )

## studyInfo:  Accessor and replacement methods
setGeneric("studyInfo", function(object)
           standardGeneric("studyInfo"))

setMethod("studyInfo", "geneSet", function(object)
	object@studyInfo)

setGeneric("studyInfo<-", function(object, value)
           standardGeneric("studyInfo<-"))

setReplaceMethod("studyInfo", "geneSet", function(object, value) {
	object@studyInfo <- value
	return(object)
})

## description:  Accessor and replacement methods
setGeneric("description", function(object)
	standardGeneric("description"))

setMethod("description", "geneSet", function(object)
	object@description)

setGeneric("description<-", function(object, value)
           standardGeneric("description<-"))

setReplaceMethod("description", "geneSet",
	function(object, value) {
		object@description <- value
		return(object)
})

## notes:  Accessor and replacement methods
setGeneric("notes", function(object)
           standardGeneric("notes"))

setMethod("notes", "geneSet", function(object)
	object@notes)

setGeneric("notes<-", function(object, value)
           standardGeneric("notes<-"))

setReplaceMethod("notes", "geneSet", function(object, value) {
	object@notes <- value
	return(object)
})

## ploidy:  Accessor and replacement methods
setGeneric("ploidy", function(object)
           standardGeneric("ploidy"))

setMethod("ploidy", "geneSet", function(object)
	object@ploidy)

setGeneric("ploidy<-", function(object, value)
           standardGeneric("ploidy<-"))

setReplaceMethod("ploidy", "geneSet", function(object, value) {
	object@ploidy <- value
	return(object)
})

## phase:  Accessor and replacement methods
setGeneric("phase", function(object)
           standardGeneric("phase"))

setMethod("phase", "geneSet", function(object)
	object@phase)

setGeneric("phase<-", function(object, value)
           standardGeneric("phase<-"))

setReplaceMethod("phase", "geneSet", function(object, value) {
	object@phase <- value
	return(object)
})


# Extract marker names
setGeneric("markerNames", function(object, ...)
           standardGeneric("markerNames"))


setMethod("markerNames", "geneSet",
          function(object, codes=FALSE)
            as.character(object@markerInfo$Name)
          )

## Extract alleles 
setGeneric("alleles", function(object, ...)
           standardGeneric("alleles"))


setMethod("alleles", "geneSet",
          function(object, which=c(1,2), codes=FALSE, marker )
            extractAlleles(object, which=which, codes=codes, marker=marker)
          )

## Extract genotypes
setGeneric("genotypes", 
           function(object, ...)
           standardGeneric("genotypes"))


setMethod("genotypes", "geneSet", function(object, codes=FALSE, marker)
            extractAlleles(object, which=0, codes=codes, marker=marker)
          )


## Number of alleles 
setGeneric("nallele", function(object, ...)
           standardGeneric("nallele"))


setMethod("nallele", "geneSet",
          function(object, marker=1:nmarker(object) )
            sapply( alleleLevels(object,marker),
                   function(x) length(na.omit(x)))
          )
